@@ -2,24 +2,18 @@ import whois
 import logging
 import requests
 
-
 def whois_plugin(data):
     try:
         hostDict = whois.whois(data)
         hostDict = dict(hostDict)
+
         # change domain list from list to string
         if isinstance(hostDict.get('domain_name'), list):
             hostDict['domain_name'] = hostDict['domain_name'][0].lower()
 
-        # add verified field
-        hostDict.update({ 'verified': False })
-
         # search for domain in 500DB
-        urlManifest = requests.get('https://raw.githubusercontent.com/Cyvore/IconDB/master/Resources/top500urls.txt').text.split('\n')
-        for url in urlManifest:
-            if hostDict['domain_name'] in url:
-                hostDict['verified'] = True
-                break
+        domainList = open('CyvoreOS\\Resources\\top500domains.txt', 'r').read().split('\n')
+        hostDict['verified'] = True if hostDict['domain_name'] in domainList else False
 
         return hostDict
     except Exception as e:
@@ -41,4 +35,4 @@ def describe():
 def tags():
     # Todo: consider adding support for ips
     tags_list = ["domain"]
-    return tags_list
+    return tags_list
\ No newline at end of file
